====================
 Configuration File
====================

|PD| provides a few user configuration options, by the use of a INI-style
configuration file called |RC| in a |RCDIR| subdirectory of your home
directory.  Here's the default settings:

.. literalinclude:: ../../ditz/config.cfg
   :language: ini
